/**********************************************************************
 * File Name: Radsim.java
 *
 * Copyright (C) 2000, US Air Force Research Laboratory,
 * Rome Research Site, Rome NY 13424, USA.
 *
 * Use of this software implies acceptance of the terms described in
 * accompanying license.txt file.
 *
 *
 * Authors: James Lawton, Jennifer Dzek, John Crowter,
 *          Bob Paragi, and Joe Beasock
 *
 * Creation Date: July 1999
 *
 * Description: The graphics frame for the RadSim simulation.
 *
 * Modification History:
 *
 **********************************************************************/


import java.awt.*;
import java.awt.event.*;

public class RadsimFrame extends Frame
{

    // member declarations
    public SimEnvironment env;
    public RadsimCanvas drawingCanvas = new RadsimCanvas();
    public RadsimStatus statusCanvas = new RadsimStatus();
    private MenuItem startStopItem = new MenuItem("Stop");

    // Constructors
    public RadsimFrame()
    {
    }

    public void initComponents(SimEnvironment simEnv) throws Exception
    {
	// the following code sets the frame's initial state
	env = simEnv;

	MenuBar menubar = new MenuBar();
	Menu RadsimMenu = new Menu("Radsim", true);
	MenuItem quitItem = new MenuItem("Quit");
	quitItem.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    //java.lang.Runtime.getRuntime().exit(0);
		    env.quitCalled = true;
		}
	    });

	startStopItem.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    if (env.running) { 
			// Stop action selected
			env.running = false;
			startStopItem.setLabel("Start");
		    }
		    else {
			//Start action selected
			env.running = true;
			startStopItem.setLabel("Stop");
		    }
		}
	    });
	
	Menu debugMenu = new Menu("Debug Level", true);
	MenuItem debug_0 = new MenuItem("None");
	debug_0.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    env.Debug = 0;
		}
	    });
	MenuItem debug_1 = new MenuItem("Basic");
	debug_1.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    env.Debug = 1;
		}
	    });
	MenuItem debug_2 = new MenuItem("Advanced");
	debug_2.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    env.Debug = 2;
		}
	    });
	MenuItem debug_3 = new MenuItem("Complete");
	debug_3.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    env.Debug = 3;
		}
	    });
	debugMenu.add(debug_0);
	debugMenu.add(debug_1);
	debugMenu.add(debug_2);
	debugMenu.add(debug_3);

	menubar.add(RadsimMenu);
	RadsimMenu.add(startStopItem);
	RadsimMenu.add(debugMenu);
	RadsimMenu.add(quitItem);

	drawingCanvas.initComponents();
	drawingCanvas.env = simEnv;
	drawingCanvas.setVisible(true);
	drawingCanvas.setBackground(Color.white);

	statusCanvas.env = simEnv;
	statusCanvas.setVisible(true);

	setTitle("Radsim Frame");
	setLayout(null);
	setSize(new java.awt.Dimension(500, 600));
	setComponentSizes();
	setMenuBar(menubar);
	add(drawingCanvas);
	add(statusCanvas);

  	addWindowListener(new java.awt.event.WindowAdapter() {
  		public void windowClosing(java.awt.event.WindowEvent e) {
  		    thisWindowClosing(e);
  		}
  	    });
	// END GENERATED CODE
    }

    private boolean mShown = false;

    public void addNotify()
    {
	super.addNotify();

	if (mShown)
	    return;

	// move components to account for insets
	Insets insets = getInsets();
	Component[] components = getComponents();
	for (int i = 0; i < components.length; i++) {
	    Point location = components[i].getLocation();
	    location.move(location.x, location.y + insets.top);
	    components[i].setLocation(location);
	}

	mShown = true;
    }

    // Close the window when the close box is clicked
    void thisWindowClosing(java.awt.event.WindowEvent e)
    {
	setVisible(false);
	dispose();
	//System.exit(0);
	env.quitCalled = true;
    }

    // Resize the window components
    void setComponentSizes() {
	Dimension d = getSize();
	int width = d.width,
	    drawHeight = (int) (0.85 * d.height),
	    statHeight = (int) (0.1 * d.height);
	
	drawingCanvas.setSize(new java.awt.Dimension(width, drawHeight));
	statusCanvas.setSize(new java.awt.Dimension(width, statHeight));
	statusCanvas.setLocation(new java.awt.Point(0, drawHeight));
    }


}
